# Overview of Graphs
TimelineFX utilises graphs in order to control how effects, emitters and particles behave overtime. There's 2 concepts of what time means in the context of graphs:

![Timeline FX Graphs](docs/images/graph.png)

### Age of Effect or Emitter
Firstly, there is the age of the effect or emitter which is measured in millisecs. When an effect is created it will also create all of the emitters that it has at the same time. The age of both the effect and it's emitters are set to 0 and then each frame the time since the last frame will be added it's age.

Each frame that passes all effects and emitters are updated and at this time their graphs will be sampled to find out what the state of the effect or emitter should be at that time. The state will consist of a varying amount of attributes such as the rotation, translation, global attributes and so on. All these values will then be used to further update particles that are being spawned and also particles already in existence that are being updated each frame also.

### Lifetime of the Particle
The second concept of time is the age of a particle. Everytime a particle is spawned it is assigned a max age by the emitter that spawns it. This age is calculated by sampling the *Base Lifetime* and *Lifetime Variation* graphs.

All graphs that sample based on the age of a particle calculate the percentage of time that a particle has existed for based on it's max age, so basically it's: current age / max age. This value between 0 and 1 is then used to sample the *Overtime* graphs.

*Overtime* graphs all sample based on this percent of time, graphs such as *Intensity Overtime*, *Size Overtime*, *Velocity Overtime* etc.

### The X Graph Axis
Each graph have the x and y axis that represent different things. The X axis of any graph that samples based on the effect or emitter age will be the time in Millisecs since the effect or emitter was created (that's all graphs other then overtime graphs).

For *Overtime* graphs, the X axis will range from 0 to 1 representing the finite time that a particle exists for. For single particles that don't expire, these graphs are looped over. So once the age of the particle is greater than the max age it is reset back to zero.

### The Y Graph Axis
The Y axis on the graphs will represent the value of that specific attribute that you're editing. So this might be the spawn rate in particles per second, size in pixels, velocity in pixels per second etc. 

### Panning and Zooming the graph
Use the scroll bars to pan the graph. To zoom in and out of the graph you can do this independently for each axis by clicking and dragging outside of the graph area where the axis label is. 

Additionally you can also use the zoom and pan icons on the graph toolbar as well. [Read more about the graph toolbar here](help_graph_toolbar)

### Nodes on the Graphs
In order to set values you simple click on the graph to place a new node. By default straight lines are drawn between nodes meaning that when the graph is sampled linear interplotion is used to get values between nodes. By right clicking on a node you can switch to node to use curves meaning that bezier curves will be used to get values between nodes for smoother results.

The first node on the graph is always set to zero on the X axis and cannot be moved from there. This is the node that the drag floats adjust in the properties window. For many effects you won't need any nodes other then the first one so this is just a convenient way that you can edit the graph value without having to access the graph.

[See editing graph nodes for more info](help_graphs_nodes)

### Multi-line graphs
Some graphs such as Rotation and Translation graphs are multi-line, meaning that you can quickly access each axis of the attribute - like pitch, yaw and roll, from the same graph by clicking the X, Y and Z buttons in the graph toolbar. There are also other tools for these graphs where you can quickly copy the values to the other lines in the graph if needed. [See multi line graphs](help_multiline_graphs) for more info.
