# Differences from the Old Version of TimelineFX

Whilst this new version of TimelineFX is similar to the previous version, there are some changes and improvements that make it differ and help orient users to the new version.

### Complete Rewrite in C++
Everything has been completely rewritten in C++, including both the editor and the library. This means that it will be a lot more portable and usable in other renderers.

The library has no dependencies and is render-agnostic, so it should be very easy to integrate into other renderers. [Click here for the TimelineFX Library on GitHub](https://github.com/peterigz/timelinefxlib).

### 3D Effects
With the previous version, only 2D effects were possible, but now you can also create 3D effects. Just toggle the 3D flag under the Effect Options. [Show Me](is_3d).

### Emission Types
Previously, emission types like point, ellipse, and area were set using the effects options. This meant that all emitters within the effect had to use that emission type too. So, if you wanted to have emitters with different emission types within the same effect, you would have to use sub-effects to do this.

In the new version, emission type is now per emitter. This makes it much easier to have different emission types for each emitter within the same effect. [Show Me](emission_type)

### Docking Interface
The user interface is much improved, allowing you to move all windows and tabs to wherever you want.

### Shape Importer
This has been much improved and is more intuitive when importing animated shapes.

### All Properties in One Place
All of the properties and attributes for effects and emitters are now in one place and also filterable by keyword. These are located on the properties tab.

### Reorganized the Graph Attributes
Before, the base, variation, and overtime graphs were grouped together, but now graphs are grouped by their respective types. For example, base size, size variation, and size overtime are all grouped under the same header, making it easier to edit these attributes.

### Editing Graphs
Graphs are edited in the same way as before, but the first node on the graph is now more easily edited using new drag inputs under the properties tab. Just click the ellipsis button next to the drag input to edit the graph as normal.

### Gravity Changes
There's been a small change to how gravity affects particles. In the previous version, if you had a base gravity of 10, this would be how much the particle would accelerate by each frame. This value is now the max speed that gravity applies, and you use the overtime graph to affect how much of the gravity takes effect. So, if you draw a graph that curves upwards, then that will essentially have the effect of accelerating the particle downwards.

### Shapes Tab
The shapes tab has a few quality of life improvements like animated shapes being interactive, allowing you to easily preview all the frames in the shape by hovering the mouse over it.

### Blending Modes
In the previous version, there was an option to switch an emitter between Additive and Alpha blending and then using the Alpha blending graph. This option is now gone and replaced by 2 graph attributes: Blend Factor and Intensity. The blend factor graph can be any value between 0 and 1 over the lifetime of the particle and will dictate how much the particles in the emitter will be alpha or additively blended. Values closer to 0 will be additively blended, and values closer to 1 will be alpha blended.

The intensity graph affects how transparent the particles are but values can also go over 1 allowing for brighter particles to be drawn: [Blend Factor Overtime](overtime_blendfactor), [Intensity Overtime](overtime_intensity).

### Motion Randomness
These attributes have been replaced by a new Simplex Noise algorithm allowing for many more options in the particle movement. However, as this noise algorithm is more expensive, more options will be coming in the future. Click on the following for the new locations of the noise settings:

[Base Noise Offset](base_noise_offset)
[Noise Offset Variation](variation_noise_offset)
[Noise Resolution](variation_noise_resolution)
[Noise Overtime](overtime_velocity_turbulance)
[Noise Resolution Overtime](overtime_noise_resolution)

### Animation Tab
There have been a few improvements to the animation tab. You can now speed up or slow down the animation playback, which allows you to fit the animation into a more specific number of frames that suit you. The seamless texture preview is much improved (2D only). And now, of course, you can export spritesheets of 3D effects as well.

A helpful masking feature has also been added that lets you easily see where the effect is being positioned in the frame.

### New Sprite Data Tab
Effects can now be baked. This means that all of the sprite data for an effect can be exported so that you can playback the sprite data using a compute shader for ultimate speed and efficiency. Not only this, but the sprite data can be compressed so it uses only a small amount of memory. For example, a 200 frame animation can be compressed down to only 20 - 50 frames. The compute shader will interpolate the sprite data for smooth playback. The sprite data settings share similarities with the animation tab such as looping.

### Delay Spawning
A new emitter property that allows you to make an emitter wait before it starts spawning particles. [Show Me](delay_spawning)

### Import Old .eff Files
To make the transition easier, you can import your old EFF files from the old editor using the tool under the File Menu. Note that it's not 100% accurate and you may have to tweak the effects due to all the changes.